bandicoot, an open-source python toolbox to analyze mobile phone metadata
=========================================================================

`bandicoot <http://bandicoot.mit.edu/>`_ is an open-source python toolbox to analyze and extract behavioral indicators from mobile phone data. It
is developed by `Yves-Alexandre de Montjoye <http://deMontjoye.com/>`_, `Luc
Rocher <https://rocher.lc>`_ and `Alex Pentland <http://web.media.mit.edu/~sandy/>`_ at the `MIT Media Lab
<http://media.mit.edu/>`_ (`Human Dynamics Group <http://hd.media.mit.edu/>`_).

The behavioral indicators computed by bandicoot have already been used to release
data as part of Orange `D4D Challenge <http://www.d4d.orange.com/home>`_, to
predict `gender, age <http://arxiv.org/abs/1511.06660>`_, and
`personality <http://web.media.mit.edu/~yva/InfographicPersonality.png>`_;
and for `customer segmentation <http://web.media.mit.edu/~yva/InfographicBigDataMarketing.png>`_.

If you use bandicoot in your research please cite it as:

.. note:: de Montjoye, Y.-A.*, Quoidbach J.*, Robic F.*, Pentland A., Predicting
          people personality using novel mobile phone-based metrics.
          International Conference on Social Computing, Behavioral-Cultural
          Modeling, & Prediction, Washington, USA (2013).

.. toctree::
	:maxdepth: 2

	quickstart
	using_bandicoot
	reference/index
	developers
	data_integrity
